************
Installation
************


*libadalina-core* can be installed using pip.
It is recommended to create a virtual environment before installation to avoid conflicts with other packages.

.. code-block::

   pip install libadalina-core

It requires a Java Runtime Environment (JRE) installed on your system to run Apache Sedona,
however, if a :code:`JAVA_HOME` environment variable is not set, *libadalina-core* will attempt to
download and install OpenJDK 17 automatically in your home directory using the :code:`install-jdk` package.


.. toctree::
   :maxdepth: 2

   amelia_integration